@@ -34,7 +34,7 @@ DIAG_PREFIELD_CALL      =
 'Will be interpreted as `{}{}`. It may be necessary to add a `,` or `;`.'
 DIAG_OVER_MAX_ARGS      =
 'The function takes only {:d} parameters, but you passed {:d}.'
-DIAG_OVER_MAX_ARGS      =
+DIAG_OVER_MAX_VALUES    =
 'Only has {} variables, but you set {} values.'
 DIAG_AMBIGUITY_1        =
 'Compute `{}` first. You may need to add brackets.'
@@ -80,7 +80,7 @@ DIAG_COSE_NON_OBJECT    =
 'Cannot close a value of this type. (Unless set `__close` meta method)'
 DIAG_COUNT_DOWN_LOOP    =
 'Do you mean `{}` ?'
-DIAG_IMPLICIT_ANY       =
+DIAG_UNKNOWN            =
 'Can not infer type.'
 DIAG_DEPRECATED         =
 'Deprecated.'
@@ -457,6 +457,13 @@ WINDOW_LUA_STATUS_CACHED_FILES   =
 'Cached files: {ast}/{max}'
 WINDOW_LUA_STATUS_MEMORY_COUNT   =
 'Memory usage: {mem:.f}M'
+WINDOW_LUA_STATUS_TIP            =
+[[
+
+This icon is a cat,
+Not a dog nor a fox!
+             ↓↓↓
+]]
 WINDOW_APPLY_SETTING             =
 'Apply setting'
 WINDOW_CHECK_SEMANTIC            =
@@ -483,6 +490,8 @@ WINDOW_APPLY_WHITOUT_SETTING     =
 'Apply but do not modify settings'
 WINDOW_ASK_APPLY_LIBRARY         =
 'Do you need to configure your work environment as `{}`?'
+WINDOW_SEARCHING_IN_FILES        =
+'Searching in files...'
 
 CONFIG_LOAD_FAILED               =
 'Unable to read the settings file: {}'
@@ -511,3 +520,16 @@ PLUGIN_TRUST_NO                  =
 [[
 Don't load this plugin
 ]]
+
+CLI_CHECK_ERROR_TYPE =
+'The argument of CHECK must be a string, but got {}'
+CLI_CHECK_ERROR_URI =
+'The argument of CHECK must be a valid uri, but got {}'
+CLI_CHECK_ERROR_LEVEL =
+'Checklevel must be one of: {}'
+CLI_CHECK_INITING =
+'Initializing ...'
+CLI_CHECK_SUCCESS =
+'Diagnosis completed, no problems found'
+CLI_CHECK_RESULTS =
+'Diagnosis complete, {} problems found, see {}'
