@@ -80,7 +80,7 @@ DIAG_COSE_NON_OBJECT    =
 '无法 close 此类型的值。（除非给此类型设置 `__close` 元方法）'
 DIAG_COUNT_DOWN_LOOP    =
 '你的意思是 `{}` 吗？'
-DIAG_IMPLICIT_ANY       =
+DIAG_UNKNOWN            =
 '无法推测出类型。'
 DIAG_DEPRECATED         =
 '已废弃。'
@@ -456,6 +456,13 @@ WINDOW_LUA_STATUS_CACHED_FILES   =
 '已缓存文件：{ast}/{max}'
 WINDOW_LUA_STATUS_MEMORY_COUNT   =
 '内存占用：{mem:.f}M'
+WINDOW_LUA_STATUS_TIP            =
+[[
+
+这个图标是猫，
+不是狗也不是狐狸！
+             ↓↓↓
+]]
 WINDOW_APPLY_SETTING             =
 '应用设置'
 WINDOW_CHECK_SEMANTIC            =
@@ -482,6 +489,8 @@ WINDOW_APPLY_WHITOUT_SETTING     =
 '应用但不修改设置'
 WINDOW_ASK_APPLY_LIBRARY         =
 '是否需要将你的工作环境配置为 `{}` ？'
+WINDOW_SEARCHING_IN_FILES        =
+'正在文件中搜索...'
 
 CONFIG_LOAD_FAILED               =
 '无法读取设置文件：{}'
@@ -510,3 +519,16 @@ PLUGIN_TRUST_NO                  =
 [[
 不要加载此插件
 ]]
+
+CLI_CHECK_ERROR_TYPE =
+'check 必须是一个字符串，但是是一个 {}'
+CLI_CHECK_ERROR_URI =
+'check 必须是一个有效的 URI，但是是 {}'
+CLI_CHECK_ERROR_LEVEL =
+'checklevel 必须是这些值之一：{}'
+CLI_CHECK_INITING =
+'正在初始化...'
+CLI_CHECK_SUCCESS =
+'诊断完成，没有发现问题'
+CLI_CHECK_RESULTS =
+'诊断完成，共有 {} 个问题，请查看 {}'
