@@ -1,7 +1,5 @@
 local files   = require 'files'
-local searcher   = require 'core.searcher'
 local lang    = require 'language'
-local define  = require 'proto.define'
 local vm      = require 'vm'
 
 return function (uri, callback)
@@ -14,10 +12,8 @@ return function (uri, callback)
         return
     end
 
-    local cache = {
-        ['any'] = true,
-        ['nil'] = true,
-    }
+    local cache = {}
+
     for _, doc in ipairs(state.ast.docs) do
         if doc.type == 'doc.class' then
             if not doc.extends then
@@ -25,11 +21,11 @@ return function (uri, callback)
             end
             for _, ext in ipairs(doc.extends) do
                 local name = ext[1]
-                local docs = vm.getDocDefines(uri, name)
+                local docs = vm.getDocSets(uri, name)
                 if cache[name] == nil then
                     cache[name] = false
                     for _, otherDoc in ipairs(docs) do
-                        if otherDoc.type == 'doc.class.name' then
+                        if otherDoc.type == 'doc.class' then
                             cache[name] = true
                             break
                         end
