@@ -1,68 +1,63 @@
 local error        = error
 local type         = type
 
----@class parser.guide.object
----@field bindDocs              parser.guide.object[]
----@field bindGroup             parser.guide.object[]
----@field bindSources           parser.guide.object[]
----@field value                 parser.guide.object
----@field parent                parser.guide.object
+---@class parser.object
+---@field bindDocs              parser.object[]
+---@field bindGroup             parser.object[]
+---@field bindSources           parser.object[]
+---@field value                 parser.object
+---@field parent                parser.object
 ---@field type                  string
 ---@field special               string
 ---@field tag                   string
----@field args                  parser.guide.object[]
----@field locals                parser.guide.object[]
----@field returns               parser.guide.object[]
+---@field args                  parser.object[]
+---@field locals                parser.object[]
+---@field returns               parser.object[]
 ---@field uri                   uri
 ---@field start                 integer
 ---@field finish                integer
 ---@field effect                integer
 ---@field attrs                 string[]
----@field specials              parser.guide.object[]
----@field labels                parser.guide.object[]
----@field node                  parser.guide.object
+---@field specials              parser.object[]
+---@field labels                parser.object[]
+---@field node                  parser.object
 ---@field dummy                 boolean
----@field field                 parser.guide.object
----@field method                parser.guide.object
----@field index                 parser.guide.object
----@field extends               parser.guide.object[]
----@field types                 parser.guide.object[]
----@field enums                 parser.guide.object[]
----@field resumes               parser.guide.object[]
----@field fields                parser.guide.object[]
----@field typeGeneric           table<integer, parser.guide.object[]>
----@field tkey                  parser.guide.object
----@field tvalue                parser.guide.object
+---@field field                 parser.object
+---@field method                parser.object
+---@field index                 parser.object
+---@field extends               parser.object[]|parser.object
+---@field types                 parser.object[]
+---@field fields                parser.object[]
+---@field tkey                  parser.object
+---@field tvalue                parser.object
 ---@field tindex                integer
----@field op                    parser.guide.object
----@field next                  parser.guide.object
----@field docParam              parser.guide.object
+---@field op                    parser.object
+---@field next                  parser.object
+---@field docParam              parser.object
 ---@field sindex                integer
----@field name                  parser.guide.object
----@field call                  parser.guide.object
----@field closure               parser.guide.object
----@field proto                 parser.guide.object
----@field exp                   parser.guide.object
----@field isGeneric             boolean
----@field alias                 parser.guide.object
----@field class                 parser.guide.object
----@field vararg                parser.guide.object
----@field param                 parser.guide.object
----@field overload              parser.guide.object
+---@field name                  parser.object
+---@field call                  parser.object
+---@field closure               parser.object
+---@field proto                 parser.object
+---@field exp                   parser.object
+---@field alias                 parser.object
+---@field class                 parser.object
+---@field vararg                parser.object
+---@field param                 parser.object
+---@field overload              parser.object
 ---@field docParamMap           table<string, integer>
 ---@field upvalues              table<string, string[]>
----@field ref                   parser.guide.object[]
+---@field ref                   parser.object[]
 ---@field returnIndex           integer
----@field docs                  parser.guide.object[]
+---@field docs                  parser.object[]
 ---@field state                 table
 ---@field comment               table
 ---@field optional              boolean
----@field _root                 parser.guide.object
----@field _noders               noders
----@field _mnode                parser.guide.object
----@field _noded                boolean
----@field _initedNoders         boolean
----@field _compiledGlobals      boolean
+---@field max                   parser.object
+---@field init                  parser.object
+---@field step                  parser.object
+---@field redundant             { max: integer, passed: integer }
+---@field _root                 parser.object
 
 ---@class guide
 ---@field debugMode boolean
@@ -96,7 +91,7 @@ local childMap = {
     ['repeat']      = {'#', 'filter'},
     ['while']       = {'filter', '#'},
     ['in']          = {'keys', 'exps', '#'},
-    ['loop']        = {'loc', 'max', 'step', '#'},
+    ['loop']        = {'loc', 'init', 'max', 'step', '#'},
     ['if']          = {'#'},
     ['ifblock']     = {'filter', '#'},
     ['elseifblock'] = {'filter', '#'},
@@ -127,8 +122,9 @@ local childMap = {
     ['unary']       = {1},
 
     ['doc']                = {'#'},
-    ['doc.class']          = {'class', '#extends', 'comment'},
-    ['doc.type']           = {'#types', '#enums', '#resumes', 'name', 'comment'},
+    ['doc.class']          = {'class', '#extends', '#signs', 'comment'},
+    ['doc.type']           = {'#types', 'name', 'comment'},
+    ['doc.type.name']      = {'#signs'},
     ['doc.alias']          = {'alias', 'extends', 'comment'},
     ['doc.param']          = {'param', 'extends', 'comment'},
     ['doc.return']         = {'#returns', 'comment'},
@@ -137,17 +133,18 @@ local childMap = {
     ['doc.generic.object'] = {'generic', 'extends', 'comment'},
     ['doc.vararg']         = {'vararg', 'comment'},
     ['doc.type.array']     = {'node'},
-    ['doc.type.table']     = {'tkey', 'tvalue', 'comment'},
     ['doc.type.function']  = {'#args', '#returns', 'comment'},
-    ['doc.type.ltable']    = {'#fields', 'comment'},
+    ['doc.type.table']     = {'#fields', 'comment'},
     ['doc.type.literal']   = {'node'},
-    ['doc.type.arg']       = {'extends'},
-    ['doc.type.field']     = {'extends'},
+    ['doc.type.arg']       = {'name', 'extends'},
+    ['doc.type.field']     = {'name', 'extends'},
     ['doc.overload']       = {'overload', 'comment'},
     ['doc.see']            = {'name', 'field'},
+    ['doc.version']        = {'#versions'},
+    ['doc.diagnostic']     = {'#names'},
 }
 
----@type table<string, fun(obj: parser.guide.object, list: parser.guide.object[])>
+---@type table<string, fun(obj: parser.object, list: parser.object[])>
 local compiledChildMap = setmetatable({}, {__index = function (self, name)
     local defs = childMap[name]
     if not defs then
@@ -227,7 +224,7 @@ local function formatNumber(n)
 end
 
 --- 是否是字面量
----@param obj parser.guide.object
+---@param obj parser.object
 ---@return boolean
 function m.isLiteral(obj)
     local tp = obj.type
@@ -238,10 +235,15 @@ function m.isLiteral(obj)
         or tp == 'integer'
         or tp == 'table'
         or tp == 'function'
+        or tp == 'doc.type.function'
+        or tp == 'doc.type.table'
+        or tp == 'doc.type.string'
+        or tp == 'doc.type.integer'
+        or tp == 'doc.type.boolean'
 end
 
 --- 获取字面量
----@param obj parser.guide.object
+---@param obj parser.object
 ---@return any
 function m.getLiteral(obj)
     local tp = obj.type
@@ -258,10 +260,10 @@ function m.getLiteral(obj)
 end
 
 --- 寻找父函数
----@param obj parser.guide.object
----@return parser.guide.object
+---@param obj parser.object
+---@return parser.object
 function m.getParentFunction(obj)
-    for _ = 1, 1000 do
+    for _ = 1, 10000 do
         obj = obj.parent
         if not obj then
             break
@@ -275,10 +277,10 @@ function m.getParentFunction(obj)
 end
 
 --- 寻找所在区块
----@param obj parser.guide.object
----@return parser.guide.object
+---@param obj parser.object
+---@return parser.object
 function m.getBlock(obj)
-    for _ = 1, 1000 do
+    for _ = 1, 10000 do
         if not obj then
             return nil
         end
@@ -304,10 +306,10 @@ function m.getBlock(obj)
 end
 
 --- 寻找所在父区块
----@param obj parser.guide.object
----@return parser.guide.object
+---@param obj parser.object
+---@return parser.object
 function m.getParentBlock(obj)
-    for _ = 1, 1000 do
+    for _ = 1, 10000 do
         obj = obj.parent
         if not obj then
             return nil
@@ -321,10 +323,10 @@ function m.getParentBlock(obj)
 end
 
 --- 寻找所在可break的父区块
----@param obj parser.guide.object
----@return parser.guide.object
+---@param obj parser.object
+---@return parser.object
 function m.getBreakBlock(obj)
-    for _ = 1, 1000 do
+    for _ = 1, 10000 do
         obj = obj.parent
         if not obj then
             return nil
@@ -341,10 +343,10 @@ function m.getBreakBlock(obj)
 end
 
 --- 寻找doc的主体
----@param obj parser.guide.object
----@return parser.guide.object
+---@param obj parser.object
+---@return parser.object
 function m.getDocState(obj)
-    for _ = 1, 1000 do
+    for _ = 1, 10000 do
         local parent = obj.parent
         if not parent then
             return obj
@@ -358,10 +360,10 @@ function m.getDocState(obj)
 end
 
 --- 寻找所在父类型
----@param obj parser.guide.object
----@return parser.guide.object
+---@param obj parser.object
+---@return parser.object
 function m.getParentType(obj, want)
-    for _ = 1, 1000 do
+    for _ = 1, 10000 do
         obj = obj.parent
         if not obj then
             return nil
@@ -374,14 +376,14 @@ function m.getParentType(obj, want)
 end
 
 --- 寻找根区块
----@param obj parser.guide.object
----@return parser.guide.object
+---@param obj parser.object
+---@return parser.object
 function m.getRoot(obj)
     local source = obj
     if source._root then
         return source._root
     end
-    for _ = 1, 1000 do
+    for _ = 1, 10000 do
         if obj.type == 'main' then
             source._root = obj
             return obj
@@ -399,7 +401,7 @@ function m.getRoot(obj)
     error('guide.getRoot overstack')
 end
 
----@param obj parser.guide.object
+---@param obj parser.object
 ---@return uri
 function m.getUri(obj)
     if obj.uri then
@@ -450,7 +452,7 @@ end
 ---@param pos integer {comment = '可见位置'}
 function m.getLocal(block, name, pos)
     block = m.getBlock(block)
-    for _ = 1, 1000 do
+    for _ = 1, 10000 do
         if not block then
             return nil
         end
@@ -502,7 +504,7 @@ end
 ---@param name string {comment = '标签名'}
 function m.getLabel(block, name)
     block = m.getBlock(block)
-    for _ = 1, 1000 do
+    for _ = 1, 10000 do
         if not block then
             return nil
         end
@@ -653,10 +655,10 @@ function m.eachSourceBetween(ast, start, finish, callback)
 end
 
 local function getSourceTypeCache(ast)
-    local cache = ast.typeCache
+    local cache = ast._typeCache
     if not cache then
         cache = {}
-        ast.typeCache = cache
+        ast._typeCache = cache
         m.eachSource(ast, function (source)
             local tp = source.type
             if not tp then
@@ -674,6 +676,10 @@ local function getSourceTypeCache(ast)
 end
 
 --- 遍历所有指定类型的source
+---@param ast parser.object
+---@param type string
+---@param callback fun(src: parser.object)
+---@return any
 function m.eachSourceType(ast, type, callback)
     local cache = getSourceTypeCache(ast)
     local myCache = cache[type]
@@ -681,10 +687,16 @@ function m.eachSourceType(ast, type, callback)
         return
     end
     for i = 1, #myCache do
-        callback(myCache[i])
+        local res = callback(myCache[i])
+        if res ~= nil then
+            return res
+        end
     end
 end
 
+---@param ast parser.object
+---@param tps string[]
+---@param callback fun(src: parser.object)
 function m.eachSourceTypes(ast, tps, callback)
     local cache = getSourceTypeCache(ast)
     for x = 1, #tps do
@@ -698,11 +710,13 @@ function m.eachSourceTypes(ast, tps, callback)
 end
 
 --- 遍历所有的source
+---@param ast parser.object
+---@param callback fun(src: parser.object)
 function m.eachSource(ast, callback)
-    local cache = ast.eachCache
+    local cache = ast._eachCache
     if not cache then
         cache = { ast }
-        ast.eachCache = cache
+        ast._eachCache = cache
         local mark = {}
         local index = 1
         while true do
@@ -781,7 +795,7 @@ function m.offsetToPositionByLines(lines, offset)
         row = (left + right) // 2
         if row == left then
             if right ~= left then
-                if lines[right] <= offset then
+                if lines[right] - 1 <= offset then
                     row = right
                 end
             end
@@ -802,21 +816,38 @@ function m.offsetToPosition(state, offset)
     return m.offsetToPositionByLines(state.lines, offset)
 end
 
+function m.getLineRange(state, row)
+    if not state.lines[row] then
+        return 0
+    end
+    local nextLineStart = state.lines[row + 1] or #state.lua
+    for i = nextLineStart - 1, state.lines[row], -1 do
+        local w = state.lua:sub(i, i)
+        if w ~= '\r' and w ~= '\n' then
+            return i - state.lines[row] + 1
+        end
+    end
+    return 0
+end
+
 local isSetMap = {
-    ['setglobal']      = true,
-    ['local']          = true,
-    ['setlocal']       = true,
-    ['setfield']       = true,
-    ['setmethod']      = true,
-    ['setindex']       = true,
-    ['tablefield']     = true,
-    ['tableindex']     = true,
-    ['tableexp']       = true,
-    ['doc.class.name'] = true,
-    ['doc.alias.name'] = true,
-    ['doc.field.name'] = true,
-    ['doc.field']      = true,
-    ['doc.type.field'] = true,
+    ['setglobal']         = true,
+    ['local']             = true,
+    ['setlocal']          = true,
+    ['setfield']          = true,
+    ['setmethod']         = true,
+    ['setindex']          = true,
+    ['tablefield']        = true,
+    ['tableindex']        = true,
+    ['tableexp']          = true,
+    ['label']             = true,
+    ['doc.class']         = true,
+    ['doc.alias']         = true,
+    ['doc.field']         = true,
+    ['doc.class.name']    = true,
+    ['doc.alias.name']    = true,
+    ['doc.field.name']    = true,
+    ['doc.type.field']    = true,
 }
 function m.isSet(source)
     local tp = source.type
@@ -876,17 +907,17 @@ function m.getKeyNameOfLiteral(obj)
     elseif tp == 'number' then
         local n = obj[1]
         if n then
-            return formatNumber(obj[1])
+            return obj[1]
         end
     elseif tp == 'integer' then
         local n = obj[1]
         if n then
-            return formatNumber(obj[1])
+            return obj[1]
         end
     elseif tp == 'boolean' then
         local b = obj[1]
         if b then
-            return tostring(b)
+            return b
         end
     end
 end
@@ -919,7 +950,7 @@ function m.getKeyName(obj)
     or     tp == 'tableindex' then
         return m.getKeyNameOfLiteral(obj.index)
     elseif tp == 'tableexp' then
-        return tostring(obj.tindex)
+        return obj.tindex
     elseif tp == 'field'
     or     tp == 'method'
     or     tp == 'doc.see.field' then
@@ -929,11 +960,11 @@ function m.getKeyName(obj)
     elseif tp == 'doc.alias' then
         return obj.alias[1]
     elseif tp == 'doc.field' then
-        return tostring(obj.field[1])
+        return obj.field[1]
     elseif tp == 'doc.field.name' then
-        return tostring(obj[1])
+        return obj[1]
     elseif tp == 'doc.type.field' then
-        return tostring(obj.name[1])
+        return obj.name[1]
     elseif tp == 'dummy' then
         return obj[1]
     end
@@ -1095,7 +1126,7 @@ function m.getPath(a, b, sameFunction)
 end
 
 ---是否是全局变量（包括 _G.XXX 形式）
----@param source parser.guide.object
+---@param source parser.object
 ---@return boolean
 function m.isGlobal(source)
     if source._isGlobal ~= nil then
@@ -1151,4 +1182,47 @@ function m.isGlobal(source)
     return false
 end
 
+function m.isInString(ast, position)
+    return m.eachSourceContain(ast, position, function (source)
+        if  source.type == 'string'
+        and source.start < position then
+            return true
+        end
+    end)
+end
+
+function m.isOOP(source)
+    if source.type == 'setmethod'
+    or source.type == 'getmethod' then
+        return true
+    end
+    if source.type == 'method'
+    or source.type == 'field'
+    or source.type == 'function' then
+        return m.isOOP(source.parent)
+    end
+    return false
+end
+
+local basicTypeMap = {
+    ['unknown']  = true,
+    ['any']      = true,
+    ['true']     = true,
+    ['false']    = true,
+    ['nil']      = true,
+    ['boolean']  = true,
+    ['number']   = true,
+    ['string']   = true,
+    ['table']    = true,
+    ['function'] = true,
+    ['thread']   = true,
+    ['userdata'] = true,
+}
+
+---@param str string
+---@return boolean
+function m.isBasicType(str)
+    return basicTypeMap[str] == true
+end
+
 return m
