@@ -18,14 +18,15 @@ local filewatch  = require 'filewatch'
 local json       = require 'json'
 local scope      = require 'workspace.scope'
 local furi       = require 'file-uri'
+local inspect    = require 'inspect'
 
 ---@async
 local function updateConfig(uri)
     config.addNullSymbol(json.null)
     local specified = cfgLoader.loadLocalConfig(uri, CONFIGPATH)
     if specified then
-        log.debug('Load config from specified', CONFIGPATH)
-        log.debug(util.dump(specified))
+        log.info('Load config from specified', CONFIGPATH)
+        log.debug(inspect(specified))
         -- watch directory
         filewatch.watch(workspace.getAbsolutePath(uri, CONFIGPATH):gsub('[^/\\]+$', ''))
         config.update(scope.override, specified)
@@ -34,22 +35,22 @@ local function updateConfig(uri)
     for _, folder in ipairs(scope.folders) do
         local clientConfig = cfgLoader.loadClientConfig(folder.uri)
         if clientConfig then
-            log.debug('Load config from client', folder.uri)
-            log.debug(util.dump(clientConfig))
+            log.info('Load config from client', folder.uri)
+            log.debug(inspect(clientConfig))
         end
 
         local rc = cfgLoader.loadRCConfig(folder.uri, '.luarc.json')
         if rc then
-            log.debug('Load config from luarc.json', folder.uri)
-            log.debug(util.dump(rc))
+            log.info('Load config from luarc.json', folder.uri)
+            log.debug(inspect(rc))
         end
 
         config.update(folder, clientConfig, rc)
     end
 
     local global = cfgLoader.loadClientConfig()
-    log.debug('Load config from client', 'fallback')
-    log.debug(util.dump(global))
+    log.info('Load config from client', 'fallback')
+    log.debug(inspect(global))
     config.update(scope.fallback, global)
 end
 
@@ -119,7 +120,7 @@ m.register 'initialized'{
     ---@async
     function (params)
         files.init()
-        local _ <close> = progress.create(workspace.getFirstScope(), lang.script.WINDOW_INITIALIZING, 0.5)
+        local _ <close> = progress.create(workspace.getFirstScope().uri, lang.script.WINDOW_INITIALIZING, 0.5)
         updateConfig()
         local registrations = {}
 
@@ -169,7 +170,7 @@ m.register 'workspace/didChangeConfiguration' {
 m.register 'workspace/didCreateFiles' {
     ---@async
     function (params)
-        log.debug('workspace/didCreateFiles', util.dump(params))
+        log.debug('workspace/didCreateFiles', inspect(params))
         for _, file in ipairs(params.files) do
             if workspace.isValidLuaUri(file.uri) then
                 files.setText(file.uri, util.loadFile(furi.decode(file.uri)), false)
@@ -180,7 +181,7 @@ m.register 'workspace/didCreateFiles' {
 
 m.register 'workspace/didDeleteFiles' {
     function (params)
-        log.debug('workspace/didDeleteFiles', util.dump(params))
+        log.debug('workspace/didDeleteFiles', inspect(params))
         for _, file in ipairs(params.files) do
             files.remove(file.uri)
             local childs = files.getChildFiles(file.uri)
@@ -195,7 +196,7 @@ m.register 'workspace/didDeleteFiles' {
 m.register 'workspace/didRenameFiles' {
     ---@async
     function (params)
-        log.debug('workspace/didRenameFiles', util.dump(params))
+        log.debug('workspace/didRenameFiles', inspect(params))
         for _, file in ipairs(params.files) do
             local text = files.getOriginText(file.oldUri)
             if text then
@@ -225,8 +226,13 @@ m.register 'workspace/didRenameFiles' {
 m.register 'textDocument/didOpen' {
     ---@async
     function (params)
-        local doc   = params.textDocument
-        local uri   = files.getRealUri(doc.uri)
+        local doc    = params.textDocument
+        local scheme = furi.split(doc.uri)
+        if scheme ~= 'file' then
+            return
+        end
+        local uri    = files.getRealUri(doc.uri)
+        log.debug('didOpen', uri)
         workspace.awaitReady(uri)
         local text  = doc.text
         files.setText(uri, text, true, function (file)
@@ -287,7 +293,7 @@ m.register 'textDocument/hover' {
                 }
             }
         end
-        local _ <close> = progress.create(scope.getScope(uri), lang.script.WINDOW_PROCESSING_HOVER, 0.5)
+        local _ <close> = progress.create(uri, lang.script.WINDOW_PROCESSING_HOVER, 0.5)
         local core = require 'core.hover'
         if not files.exists(uri) then
             return nil
@@ -319,7 +325,7 @@ m.register 'textDocument/definition' {
         if not files.exists(uri) then
             return nil
         end
-        local _ <close> = progress.create(scope.getScope(uri), lang.script.WINDOW_PROCESSING_DEFINITION, 0.5)
+        local _ <close> = progress.create(uri, lang.script.WINDOW_PROCESSING_DEFINITION, 0.5)
         local core   = require 'core.definition'
         local pos = converter.unpackPosition(uri, params.position)
         local result = core(uri, pos)
@@ -361,7 +367,7 @@ m.register 'textDocument/typeDefinition' {
         if not files.exists(uri) then
             return nil
         end
-        local _ <close> = progress.create(scope.getScope(uri), lang.script.WINDOW_PROCESSING_TYPE_DEFINITION, 0.5)
+        local _ <close> = progress.create(uri, lang.script.WINDOW_PROCESSING_TYPE_DEFINITION, 0.5)
         local core   = require 'core.type-definition'
         local pos = converter.unpackPosition(uri, params.position)
         local result = core(uri, pos)
@@ -403,7 +409,7 @@ m.register 'textDocument/references' {
         if not files.exists(uri) then
             return nil
         end
-        local _ <close> = progress.create(scope.getScope(uri), lang.script.WINDOW_PROCESSING_REFERENCE, 0.5)
+        local _ <close> = progress.create(uri, lang.script.WINDOW_PROCESSING_REFERENCE, 0.5)
         local core   = require 'core.reference'
         local pos    = converter.unpackPosition(uri, params.position)
         local result = core(uri, pos)
@@ -463,7 +469,7 @@ m.register 'textDocument/rename' {
         if not files.exists(uri) then
             return nil
         end
-        local _ <close> = progress.create(scope.getScope(uri), lang.script.WINDOW_PROCESSING_RENAME, 0.5)
+        local _ <close> = progress.create(uri, lang.script.WINDOW_PROCESSING_RENAME, 0.5)
         local core = require 'core.rename'
         local pos    = converter.unpackPosition(uri, params.position)
         local result = core.rename(uri, pos, params.newName)
@@ -523,7 +529,7 @@ m.register 'textDocument/completion' {
                 }
             }
         end
-        local _ <close> = progress.create(scope.getScope(uri), lang.script.WINDOW_PROCESSING_COMPLETION, 0.5)
+        local _ <close> = progress.create(uri, lang.script.WINDOW_PROCESSING_COMPLETION, 0.5)
         --log.info(util.dump(params))
         local core  = require 'core.completion'
         --log.debug('textDocument/completion')
@@ -613,6 +619,9 @@ m.register 'textDocument/completion' {
             end
             items[i] = item
         end
+        if result.incomplete == nil then
+            result.incomplete = false
+        end
         return {
             isIncomplete = result.incomplete,
             items        = items,
@@ -674,7 +683,7 @@ m.register 'textDocument/signatureHelp' {
         if not files.exists(uri) then
             return nil
         end
-        local _ <close> = progress.create(scope.getScope(uri), lang.script.WINDOW_PROCESSING_SIGNATURE, 0.5)
+        local _ <close> = progress.create(uri, lang.script.WINDOW_PROCESSING_SIGNATURE, 0.5)
         local pos = converter.unpackPosition(uri, params.position)
         local core = require 'core.signature'
         local results = core(uri, pos)
@@ -717,7 +726,7 @@ m.register 'textDocument/documentSymbol' {
     function (params)
         local uri   = files.getRealUri(params.textDocument.uri)
         workspace.awaitReady(uri)
-        local _ <close> = progress.create(scope.getScope(uri), lang.script.WINDOW_PROCESSING_SYMBOL, 0.5)
+        local _ <close> = progress.create(uri, lang.script.WINDOW_PROCESSING_SYMBOL, 0.5)
 
         local core = require 'core.document-symbol'
         local symbols = core(uri)
@@ -843,7 +852,7 @@ m.register 'workspace/symbol' {
     abortByFileUpdate = true,
     ---@async
     function (params)
-        local _ <close> = progress.create(workspace.getFirstScope(), lang.script.WINDOW_PROCESSING_WS_SYMBOL, 0.5)
+        local _ <close> = progress.create(workspace.getFirstScope().uri, lang.script.WINDOW_PROCESSING_WS_SYMBOL, 0.5)
         local core = require 'core.workspace-symbol'
 
         local symbols = core(params.query)
@@ -871,21 +880,6 @@ m.register 'workspace/symbol' {
     end
 }
 
-m.register 'textDocument/semanticTokens/full' {
-    abortByFileUpdate = true,
-    ---@async
-    function (params)
-        local uri = files.getRealUri(params.textDocument.uri)
-        workspace.awaitReady(uri)
-        local _ <close> = progress.create(scope.getScope(uri), lang.script.WINDOW_PROCESSING_SEMANTIC_FULL, 0.5)
-        local core = require 'core.semantic-tokens'
-        local results = core(uri, 0, math.huge)
-        return {
-            data = results
-        }
-    end
-}
-
 local function toArray(map)
     local array = {}
     for k in pairs(map) do
@@ -897,6 +891,29 @@ local function toArray(map)
     return array
 end
 
+m.register 'textDocument/semanticTokens/full' {
+    capability = {
+        semanticTokensProvider = {
+            legend = {
+                tokenTypes     = toArray(define.TokenTypes),
+                tokenModifiers = toArray(define.TokenModifiers),
+            },
+            full  = true,
+        },
+    },
+    ---@async
+    function (params)
+        log.debug('textDocument/semanticTokens/full')
+        local uri = files.getRealUri(params.textDocument.uri)
+        workspace.awaitReady(uri)
+        local _ <close> = progress.create(uri, lang.script.WINDOW_PROCESSING_SEMANTIC_FULL, 0.5)
+        local core = require 'core.semantic-tokens'
+        local results = core(uri, 0, math.huge)
+        return {
+            data = results
+        }
+    end
+}
 
 m.register 'textDocument/semanticTokens/range' {
     capability = {
@@ -906,7 +923,6 @@ m.register 'textDocument/semanticTokens/range' {
                 tokenModifiers = toArray(define.TokenModifiers),
             },
             range = true,
-            full  = false,
         },
     },
     ---@async
@@ -914,7 +930,7 @@ m.register 'textDocument/semanticTokens/range' {
         log.debug('textDocument/semanticTokens/range')
         local uri = files.getRealUri(params.textDocument.uri)
         workspace.awaitReady(uri)
-        local _ <close> = progress.create(scope.getScope(uri), lang.script.WINDOW_PROCESSING_SEMANTIC_RANGE, 0.5)
+        local _ <close> = progress.create(uri, lang.script.WINDOW_PROCESSING_SEMANTIC_RANGE, 0.5)
         local core = require 'core.semantic-tokens'
         local start, finish = converter.unpackRange(uri, params.range)
         local results = core(uri, start, finish)
@@ -1003,7 +1019,6 @@ m.register 'textDocument/formatting' {
     capability = {
         documentFormattingProvider = true,
     },
-    preview = true,
     ---@async
     function(params)
         local uri = files.getRealUri(params.textDocument.uri)
@@ -1020,7 +1035,7 @@ m.register 'textDocument/formatting' {
         pformatting.updateConfig(uri)
 
         local core = require 'core.formatting'
-        local edits = core(uri)
+        local edits = core(uri, params.options)
         if not edits or #edits == 0 then
             return nil
         end
@@ -1041,7 +1056,6 @@ m.register 'textDocument/rangeFormatting' {
     capability = {
         documentRangeFormattingProvider = true,
     },
-    preview = true,
     ---@async
     function(params)
         local uri = files.getRealUri(params.textDocument.uri)
@@ -1058,7 +1072,7 @@ m.register 'textDocument/rangeFormatting' {
         pformatting.updateConfig(uri)
 
         local core = require 'core.rangeformatting'
-        local edits = core(uri, params.range)
+        local edits = core(uri, params.range, params.options)
         if not edits or #edits == 0 then
             return nil
         end
@@ -1087,7 +1101,7 @@ m.register 'textDocument/onTypeFormatting' {
     function (params)
         local uri    = files.getRealUri(params.textDocument.uri)
         workspace.awaitReady(uri)
-        local _ <close> = progress.create(scope.getScope(uri), lang.script.WINDOW_PROCESSING_TYPE_FORMATTING, 0.5)
+        local _ <close> = progress.create(uri, lang.script.WINDOW_PROCESSING_TYPE_FORMATTING, 0.5)
         local ch     = params.ch
         if not files.exists(uri) then
             return nil
@@ -1163,7 +1177,7 @@ do
         workspace.awaitReady(uri)
         local edits = {}
         local hint = require 'core.hint'
-        local _ <close> = progress.create(scope.getScope(uri), lang.script.WINDOW_PROCESSING_HINT, 0.5)
+        local _ <close> = progress.create(uri, lang.script.WINDOW_PROCESSING_HINT, 0.5)
         for _, visible in ipairs(visibles) do
             local piece = hint(uri, visible.start, visible.finish)
             if piece then
